==> haskell-filepattern-0.1.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filepattern
version:              0.1.2
visibility:           public
id:                   filepattern-0.1.2-HIZx3a8Tvv31OrCpFRdNZH
key:                  filepattern-0.1.2-HIZx3a8Tvv31OrCpFRdNZH
license:              BSD-3-Clause
copyright:            Neil Mitchell 2011-2020
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:
    Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>

homepage:             https://github.com/ndmitchell/filepattern#readme
synopsis:             File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:

    * All matching is /O(n)/. Most functions precompute some information given only one argument.

    * See "System.FilePattern" and @?==@ simple matching and semantics.

    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.

    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.

    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.

    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.

category:             Development, FilePath
abi:                  6c9301942b3963f76c0cab8ca92db0fe
exposed:              True
exposed-modules:      System.FilePattern System.FilePattern.Directory
hidden-modules:
    System.FilePattern.Core System.FilePattern.ListBy
    System.FilePattern.Monads System.FilePattern.Step
    System.FilePattern.Tree System.FilePattern.Wildcard

import-dirs:          /usr/lib/ghc-8.10.1/site-local/filepattern-0.1.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/filepattern-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/filepattern-0.1.2
hs-libraries:         HSfilepattern-0.1.2-HIZx3a8Tvv31OrCpFRdNZH
depends:
    base-4.14.0.0 directory-1.3.6.0 extra-1.7.3-GomQNbcl6YY7V7NWYrpLTh
    filepath-1.4.2.1

haddock-interfaces:   /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html:         /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filepattern-0.1.2-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filepattern
version:              0.1.2
visibility:           public
id:                   filepattern-0.1.2-I75hGGvpx309U3qUxXN4xA
key:                  filepattern-0.1.2-I75hGGvpx309U3qUxXN4xA
license:              BSD-3-Clause
copyright:            Neil Mitchell 2011-2020
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:
    Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>

homepage:             https://github.com/ndmitchell/filepattern#readme
synopsis:             File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:

    * All matching is /O(n)/. Most functions precompute some information given only one argument.

    * See "System.FilePattern" and @?==@ simple matching and semantics.

    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.

    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.

    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.

    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.

category:             Development, FilePath
abi:                  bae48b247b9a0e693ccd3feb26efbdab
exposed:              True
exposed-modules:      System.FilePattern System.FilePattern.Directory
hidden-modules:
    System.FilePattern.Core System.FilePattern.ListBy
    System.FilePattern.Monads System.FilePattern.Step
    System.FilePattern.Tree System.FilePattern.Wildcard

import-dirs:          /usr/lib/ghc-8.10.1/site-local/filepattern-0.1.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/filepattern-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/filepattern-0.1.2
hs-libraries:         HSfilepattern-0.1.2-I75hGGvpx309U3qUxXN4xA
depends:
    base-4.14.0.0 directory-1.3.6.0 extra-1.7.5-69pFNvIQi1iLl09c5xrsXp
    filepath-1.4.2.1

haddock-interfaces:   /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html:         /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
